{ pkgs, ... }:
{
    programs.tmux = {
        shell = "${pkgs.zsh}/bin/zsh";
        terminal = "tmux-256color";
        enable = true;
        clock24 = true;
        shortcut = "a";
        escapeTime = 0;
        newSession = true;
        mouse = true;
        keyMode = "vi";
        plugins = [
            pkgs.tmuxPlugins.vim-tmux-navigator
            pkgs.tmuxPlugins.better-mouse-mode
            pkgs.tmuxPlugins.yank
            {
                plugin = pkgs.tmuxPlugins.catppuccin;
                extraConfig = ''
                    set -ogq @catppuccin_flavor "mocha"
                    set -ogq @catppuccin_window_status_style "rounded"
                    set -ogq @catppuccin_window_current_number_color "#1F2430"
                    set -ogq @catppuccin_window_current_text_color "#0F7FCF"
                    set -ogq @catppuccin_window_number_color "#181825"
                    set -ogq @catppuccin_window_text_color "#5a5d70"
                    set -ogq @catppuccin_window_current_text " #{b:pane_current_path}"
                    set -ogq @catppuccin_window_text " #{b:pane_current_path}"
                    set -ogq @catppuccin_pane_border_style "fg=#181825"
                    set -ogq @catppuccin_pane_active_border_style "fg=#023269"
                    set -ogq @catppuccin_directory_color "#0F7FCF"
                    set -ogq @catppuccin_date_time_text "%Y-%m-%d %H:%M:%S"
                    set -ogq @catppuccin_menu_selected_style "fg=#{@thm_gray},bg=#0F7FCF"
                    set -ogq @catppuccin_status_background "default"
                    set -ogq status-right "#{E:@catppuccin_status_directory}"
                '';
            }
        ];

        extraConfig = ''
            set -ag terminal-overrides ",xterm-256color:RGB"
            set-window-option -g mode-keys vi
            bind-key -T copy-mode-vi 'v' send -X begin-selection
            bind-key -T copy-mode-vi 'y' send -X copy-selection

            bind | split-window -h -c "#{pane_current_path}"
            bind - split-window -v -c "#{pane_current_path}"
            bind c new-window -c "#{pane_current_path}"
            unbind '"'
            unbind %

            set -g base-index 1
            setw -g pane-base-index 1
            set-option -g renumber-windows on
        '';
    };
}
